@@ -1,11 +1,11 @@
 use Module::Build;
 my $build = Module::Build->new(
 	module_name => 'Object::Hybrid',
-	dist_version => '0.03_04',
+	dist_version => '0.03_5',
 	license  => 'perl',
 	requires => {
 		'perl'           => '5.006',
-		'Class::Tag'     => 0,
+		#'Class::Tag'     => 0, # now included, so it is not a prerequisite build
 		#'Some::Module'  => '1.23',
 		#'Other::Module' => '>= 1.2, != 1.5, < 2.0',
 	},
